diff mbox

[21/54] block: Require .bdrv_child_perm() with child nodes

Message ID 1487689130-30373-22-git-send-email-kwolf@redhat.com (mailing list archive)
State New, archived
Headers show

Commit Message

Kevin Wolf Feb. 21, 2017, 2:58 p.m. UTC
All block drivers that can have child nodes implement .bdrv_child_perm()
now. Make this officially a requirement by asserting that only drivers
without children can omit .bdrv_child_perm().

Signed-off-by: Kevin Wolf <kwolf@redhat.com>
---
 block.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

Comments

Max Reitz Feb. 22, 2017, 2:14 p.m. UTC | #1
On 21.02.2017 15:58, Kevin Wolf wrote:
> All block drivers that can have child nodes implement .bdrv_child_perm()
> now. Make this officially a requirement by asserting that only drivers
> without children can omit .bdrv_child_perm().
> 
> Signed-off-by: Kevin Wolf <kwolf@redhat.com>
> ---
>  block.c | 6 ++++--
>  1 file changed, 4 insertions(+), 2 deletions(-)

Reviewed-by: Max Reitz <mreitz@redhat.com>
diff mbox

Patch

diff --git a/block.c b/block.c
index 6d1362e..1c5f211 100644
--- a/block.c
+++ b/block.c
@@ -1361,8 +1361,9 @@  static int bdrv_check_perm(BlockDriverState *bs, uint64_t cumulative_perms,
                                     cumulative_shared_perms, errp);
     }
 
     /* Drivers may not have .bdrv_child_perm() */
     if (!drv->bdrv_child_perm) {
+        assert(QLIST_EMPTY(&bs->children));
         return 0;
     }
 
@@ -1421,8 +1422,9 @@  static void bdrv_set_perm(BlockDriverState *bs, uint64_t cumulative_perms,
         drv->bdrv_set_perm(bs, cumulative_perms, cumulative_shared_perms);
     }
 
     /* Drivers may not have .bdrv_child_perm() */
     if (!drv->bdrv_child_perm) {
+        assert(QLIST_EMPTY(&bs->children));
         return;
     }
@@ -1361,8 +1361,9 @@  static int bdrv_check_perm(BlockDriverState *bs, uint64_t cumulative_perms,
     }
 
-    /* Drivers may not have .bdrv_child_perm() */
+    /* Drivers that never have children can omit .bdrv_child_perm() */
     if (!drv->bdrv_child_perm) {
@@ -1421,8 +1422,9 @@  static void bdrv_set_perm(BlockDriverState *bs, uint64_t cumulative_perms,
     }
 
-    /* Drivers may not have .bdrv_child_perm() */
+    /* Drivers that never have children can omit .bdrv_child_perm() */
     if (!drv->bdrv_child_perm) {